=======
withenv
=======

.. image:: https://travis-ci.org/ionrock/withenv.png?branch=master
        :target: https://travis-ci.org/ionrock/withenv

.. image:: https://badge.fury.io/py/withenv.svg
        :target: https://pypi.python.org/pypi/withenv


We use environment variables all the time, but they can be painful to
maintain because a shell is sticky. It is too easy to set an
environment variable in your shell, only to have that variable stick
around when you change projects.

`withenv` aims to help this problem by providing a simple way to
prefix commands targeting YAML files that will be added to the
environment prior to the command running.

See the docs_ for more info.

* Free software: BSD license
* Documentation: https://withenv.readthedocs.org


.. _docs: https://withenv.readthedocs.org
